#!/bin/sh
#
# (c) 2000 Sun Microsystems, Inc.
#

# interface script for the QS qsub command
#
# $1 = script_file
# $2 = codine_job_id
# $3 = req_name
# $4 = std_err_out
# $5 = s_cpu
# $6 = s_rss
# $7 = arguments to script
# $8 = arguments to nqs (qsub -qs_args ... -qs_end)
# $9 = qsub -s flag
# set -x

# set PATH - better safe than sorry
PATH=/bin:/usr/bin:/usr/bsd:/usr/etc:$PATH
export PATH

# set host that we conect to via rsh
QSI_MACHINE=hosti

# determine output redirection
if [ "$4" = "" ]; then
	# separated stdout/err
	OUTOPT="-o output.$2 -e error.$2"
else
	# all in one
	OUTOPT="-eo -o errout.$2"
fi

# tmp file to store error output - dont forget to remove
ERRFILE=/usr/tmp/interface.err.$$

# The scriptfile basenames for later use
SCRIPT=script.$2
ESCRIPT=env_script.$2

# copy jobscript to cray
rcp $1 $QSI_MACHINE:$SCRIPT
if [ $? != 0 ]; then
   echo "ERROR: remote copy to $QSI_MACHINE failed" >&2
   exit 1
fi

# complete environment script in /usr/tmp and copy it to cray
cat ../env_script > /usr/tmp/$ESCRIPT

# if a shell is given on qsub commandline we use it to start the script
if [ "$9" != "" ]; then
	echo $9 " " >> /usr/tmp/$ESCRIPT
fi
echo "$SCRIPT $7" >> /usr/tmp/$ESCRIPT
rcp /usr/tmp/$ESCRIPT $QSI_MACHINE:$ESCRIPT

# make it executable
rsh $QSI_MACHINE chmod o+x $ESCRIPT

# remove temporary copy
rm /usr/tmp/$ESCRIPT


# the remote qsub execution; stdout goes to output, stderr to $ERRFILE
output=`rsh $QSI_MACHINE qsub $OUTOPT $8 -r $3 -lT $5 -lM $6 env_script.$2 2> $ERRFILE`

## no longer needed - clean up
# clean up in finished script
# rsh $QSI_MACHINE rm $SCRIPT 

# We do not get a correct exit status from rsh
# ==> parse stdout for success message
reqline=`echo $output | grep Submitted`
if [ $? -eq 1 ]; then
  # we didn't succeed - print error message, clean up and exit
  cat $ERRFILE 1>&2
  rm $ERRFILE
  exit 1
fi

# We succeeded, so we just need retrieve the job-id
echo $reqline | tr -s "><" "  " | cut -f5 -d" "

# clean up and exit
rm $ERRFILE
exit 0
